@@ -4,7 +4,6 @@
 ///  - `ormlite::Model`, giving it direct database access, e.g. `insert`, `update_all_fields`, etc.
 ///  - `ormlite::HasModelBuilder`, letting it build partials, so you can insert or update some
 ///    fields instead of all of them at once, e.g. `model.name("John").update()`
-///  - `ormlite::HasQueryBuilder`, letting it build queries, e.g. `Model::select()`
 ///  - `ormlite::TableMeta`, which you typically don't use directly, but provides table metadata
 ///    (e.g. table name)
 ///
@@ -23,7 +22,7 @@ where
     fn update_partial(&'a self) -> ModelBuilder;
 }
 
-/// A struct that is `Insertable` is expected to have same fields as the model, excluding fields
+/// A struct that is `HasInsert` is expected to have same fields as the model, excluding fields
 /// that have sane defaults at the database level. Concretely, if you have a Person struct:
 /// #[derive(ormlite::Model)]
 /// struct Person {
@@ -32,18 +31,18 @@ where
 ///     age: i32,
 /// }
 ///
-/// Then the `Insertable` struct looks like:
+/// Then the `HasInsert` struct looks like:
 /// struct InsertPerson {
 ///     name: String,
 ///     age: i32,
 /// }
-pub trait Insertable<'a, DB>
+pub trait HasInsert<DB>
 where
     Self: Sized + Send + Sync,
     DB: sqlx::Database,
 {
     type Model;
-    fn insert<'e: 'a, E>(self, db: E) -> BoxFuture<'a, Result<Self::Model>>
+    fn insert<'e, E>(self, db: E) -> BoxFuture<'e, Result<Self::Model>>
     where
         E: 'e + sqlx::Executor<'e, Database = DB>;
 }
@@ -65,12 +64,17 @@ where
         E: 'e + sqlx::Executor<'e, Database = DB>;
 }
 
-/// The core trait. a struct that implements `Model` can also implement `HasModelBuilder`, `HasQueryBuilder` (and is required to implement `Insertable`)
+/// The core trait. a struct that implements `Model` can also implement `HasModelBuilder`, (and is required to implement `HasInsert`)
 pub trait Model<DB>
 where
     DB: sqlx::Database,
     Self: Sized,
 {
+    fn table_name() -> &'static str;
+    fn fields() -> &'static [&'static str];
+    fn num_fields() -> usize;
+    fn primary_key_column() -> &'static str;
+
     fn insert<'e, E>(self, db: E) -> BoxFuture<'e, Result<Self>>
     where
         E: 'e + sqlx::Executor<'e, Database = DB>;
@@ -92,19 +96,6 @@ where
     fn query(
         query: &str,
     ) -> sqlx::query::QueryAs<DB, Self, <DB as sqlx::database::HasArguments>::Arguments>;
-}
 
-pub trait HasQueryBuilder<DB>
-where
-    DB: sqlx::Database,
-    Self: Sized,
-{
     fn select<'args>() -> SelectQueryBuilder<'args, DB, Self>;
-}
-
-pub trait TableMeta {
-    fn table_name() -> &'static str;
-    fn fields() -> &'static [&'static str];
-    fn num_fields() -> usize;
-    fn primary_key_column() -> &'static str;
-}
+}
\ No newline at end of file
